@@ -1,5 +1,5 @@
 #!/usr/local/bin/perl
-# @(#)Brcd.pm    1.3
+# @(#)Brcd.pm	1.5
 
 package Net::Brcd;
 
@@ -14,7 +14,7 @@ use constant DEBUG => 0;
 use base qw(Exporter);
 
 # Variables de gestion du package
-our $VERSION      = 0.202;
+our $VERSION      = 0.12;
 
 # Variables prives
 my $_brcd_wwn_re     = join(":",("[0-9A-Za-z][0-9A-Za-z]") x 8);
@@ -52,7 +52,7 @@ sub connect {
 
 sub proto_connect {
     my ($self,$switch,$user,$pass) = @_;
-
+    
     croak __PACKAGE__, "Error - proto_connect is a virtual function.\n";
 }
 
@@ -76,7 +76,7 @@ sub sendeof {
 
 sub readline {
     my ($self, $arg_ref) = @_;
-
+    
     croak __PACKAGE__, "Error - readline is a virtual function.\n";
 }
 
@@ -87,7 +87,7 @@ sub cfgSave {
         @_,
     );
     my @rc   = $self->cmd('cfgSave');
-
+    
     my $rc = '';
     SWITCH: {
         DEBUG && warn "DEBUG:cfgsave", Dumper(\@rc);
@@ -98,10 +98,10 @@ sub cfgSave {
             warn join("\n", @rc), "\n";
         }
         $rc   = pop @rc;
-        return 1 if ($rc =~ m/Nothing/i); # Pas de modif
+        return 1 if ($rc =~ m/Nothing/i); # Pas de modif 
         return 1 if ($rc =~ m/Updating/i); # Update fait
     }
-
+    
     croak "Error - Cannot save current configuration: $rc.\n";
 }
 
@@ -148,12 +148,12 @@ sub aliShow {
                 $fab->{ALIAS}->{$alias} = (@wwn_for_alias == 1) ? $wwn_for_alias[0]
                                                                 : \@wwn_for_alias;
             }
-
+           
             next;
         }
-
+        
         next if $args{-onlywwn};
-
+        
         if ($alias && m/(${_brcd_port_id})/) {
             my $port_id = $1;
             $fab->{PORTID}->{$port_id} = $alias;
@@ -165,7 +165,7 @@ sub aliShow {
     DEBUG && warn "DEBUG:zone.?:", Dumper($fab);
 
     return ($args{'-bywwn'})  ? (%{$fab->{WWN}})    :
-           ($args{'-byport'}) ? (%{$fab->{PORTID}}) :
+           ($args{'-byport'}) ? (%{$fab->{PORTID}}) :                  
                                 (%{$fab->{ALIAS}});
 }
 
@@ -199,7 +199,7 @@ sub zoneShow {
             }
         }
     }
-
+    
     unless ($fab->{MEMBER} and $fab->{ZONE}) {
         croak "Warning - Empty zone.\n";
     }
@@ -252,30 +252,41 @@ DEBUG && warn  "SWITCHSHOW   : $_\n";
             $fab->{$1} = $2;
             next;
         }
-#12000 :     0    1    0   id    2G   Online    E-Port  (Trunk port, master is Slot  1 Port
-#4100  :     0   0   id    2G   Online    E-Port  10:00:00:05:1e:35:f6:e5 "PS4100A"
-#3800  :port  0: id 2G Online         F-Port 50:06:01:60:10:60:04:26
-#48000 :  13    1   13   0a0d00   id    N2   Online           F-Port  10:00:00:00:c9:35:99:4b
+#12000 :  0    1    0   id    2G   Online    E-Port  (Trunk port, master is Slot  1 Port
+#48000 : 13    1   13   0a0d00   id    N2   Online           F-Port  10:00:00:00:c9:35:99:4b
 #48000 : 12    1   12   0a0c00   id    N4   No_Light
+#4100  :       0   0            id    2G   Online    E-Port  10:00:00:05:1e:35:f6:e5 "PS4100A"       
+#5100  :       0   0   010000   id    N4   Online      FC  F-Port  50:0a:09:81:98:4c:a8:9d
+#5100  :       1   1   010100   id    N4   No_Light    FC  
+#3800  : port  0: id 2G Online         F-Port 50:06:01:60:10:60:04:26
+      
         if (m{
-            ^[port\s]*(\d+):? \s*        # Le port number forme ok:port 1: ; 12;144
+            ^[port\s]*(\d+):? \s*     # Le port number forme ok:port 1: ; 12;144
             (?:
                 (?:
-                  (\d+)\s+               # Le slot que sur les directeurs
+                  (\d{1,3})\s+        # Le slot que sur les directeurs
                 )?
-                (\d+)\s*                 # Le port dans le slot
+                (\d{1,3})             # Le port dans le slot
+                \s*              
+                (
+                [0-9a-zA-Z]
+                [0-9a-zA-Z]
+                [0-9a-zA-Z]
+                [0-9a-zA-Z]
+                [0-9a-zA-Z]
+                [0-9a-zA-Z]
+                )?              # Adresse FC, qu' partir de FabOS 5.2.0a
             )?
-            ([0-9a-zA-Z]+)?               # Adresse FC, qu' partir de FabOS 5.2.0a
-            \s+ id \s+                   # Le mot magique qui dit que c'est la bonne ligne
+            \s+ [i-][d-] \s+             # Le mot magique qui dit que c'est la bonne ligne
             [a-zA-Z]*(\d+)[a-zA-Z]*  \s+ # Vitesse du port plusieurs format  priori toujours en Go/s
             (\w+)  \s*                   # Status du port
             (.*)                         # Toutes les autres informations (notamment le WWN si connects)
         }mxs) {
 DEBUG && warn  "SWITCHSHOW-RE: #$1# #$2# #$3# #$4# #$5# #$6# #$7#\n";
             # Rcupration des champs, les champs dans les mme ordre que les $
-            my @fields = qw(SLOT NUMBER ADDRESS SPEED STATUS INFO);
+            my @fields = qw(SLOT NUMBER ADDRESS SPEED STATUS INFO);              
             my $port_number  = $1;
-            my $port_info    = $7;
+            my $port_info    = $7;  
             foreach my $re ($2, $3, $4, $5, $6, $7) {
                 my $field = shift @fields;
                 if (defined $re) {
@@ -293,7 +304,7 @@ DEBUG && warn  "SWITCHSHOW-RE: #$1# #$2# #$3# #$4# #$5# #$6# #$7#\n";
                 my ($type, $wwn) = ($1,$2);
                 $fab->{PORT}->{$port_number}->{TYPE} = $type;
                 $fab->{PORT}->{$port_number}->{WWN}  = $wwn   if $wwn;
-
+                
 
                 if ($type eq "F-Port") {
                     $wwn{$wwn} = $port_number;
@@ -313,27 +324,27 @@ DEBUG && warn  "SWITCHSHOW-RE: #$1# #$2# #$3# #$4# #$5# #$6# #$7#\n";
 sub toSlot {
     my $self        = shift;
     my $port_number = shift;
-
+    
     my $fab_name = $self->{FABRIC};
     my $fab      = $self->{FABRICS}->{$fab_name};
 
 DEBUG && warn "TOSLOT: $port_number\n";
-
+    
     unless (exists $fab->{PORT}->{$port_number}) {
         $@ = __PACKAGE__.":toSlot: port number $port_number does not exist\n";
-
+        
 DEBUG && warn "$@\n";
 
         return;
     }
     unless (exists $fab->{PORT}->{$port_number}->{SLOT}) {
-
+    
         $@ = __PACKAGE__.":toSlot: port number $port_number is not a director\n";
 DEBUG && warn "$@\n";
 
         return;
     }
-
+    
 DEBUG && warn "TOSLOT: ",$fab->{PORT}->{$port_number}->{SLOT}."/".$fab->{PORT}->{$port_number}->{NUMBER},"\n";
 
     return (wantarray())?($fab->{PORT}->{$port_number}->{SLOT},$fab->{PORT}->{$port_number}->{NUMBER}):
@@ -346,22 +357,22 @@ sub portShow {
 
     my $fab_name = $self->{FABRIC};
     my $fab      = $self->{FABRICS}->{$fab_name};
-
+    
 DEBUG && warn "PORTSHOW-PORTNUMBER:test: $port_number\n";
     $port_number = $self->toSlot($port_number) || $port_number;
 DEBUG && warn "PORTSHOW-PORTNUMBER:set: $port_number\n";
     my (%port, $param, $value, $portname);
-
+    
     no warnings;
-    foreach ($self->cmd("portShow $port_number")) {
+    foreach ($self->cmd("portShow $port_number")) {    
 DEBUG && warn "PORTSHOW:parse: $_\n";
 
         if (m/^([\w\s]+):\s+(.+)/) {
             $param        = $1;
             $value        = $2;
-
+            
 DEBUG && warn "PORTSHOW: param #$param# value #$value#\n";
-
+            
             $port{$param} = $value;
             SWITCH: {
                 if ($param eq 'portName') {
@@ -372,12 +383,12 @@ DEBUG && warn "PORTSHOW: param #$param# value #$value#\n";
             }
             next;
         }
-
+        
         if (m/^([\w\s]+):\s*$/) {
             $param = $1;
             next;
         }
-
+        
         if (m/^\s+(.+)/) {
             $port{$param} = $1;
             next;
@@ -405,7 +416,7 @@ sub fabricShow {
           @_
           );
     my (%fabric,%domain);
-
+    
     foreach ($self->cmd('fabricShow')) {
         next unless $_;
 DEBUG && warn "DEBUG:: $_\n";
@@ -424,36 +435,36 @@ DEBUG && warn "DEBUG:: $_\n";
                 if ($re) {
                     $domain{$domain_id}->{$field}   = $re;
                     $fabric{$switch_name}->{$field} = $re;
-                }
+                } 
             }
-
+            
             $fabric{$switch_host} = $switch_name if $switch_host;
         }
     }
-
+    
     return ($args{-bydomain}) ? (%domain) :
                                 (%fabric);
 }
 
 sub currentFabric {
     my $self = shift;
-
+    
     return $self->{FABRIC};
 }
 
 
 sub isWwn {
-    my $self = shift;
+    my $self = shift;    
     my $wwn = shift;
-
+    
     ($wwn =~ m/^${_brcd_wwn_re}/)?(return 1):(return);
-
+    
 }
 
 sub portAlias {
     my $self = shift;
     my $port_alias = shift;
-
+    
     if ($port_alias =~ m/(\d+),(\d+)/){
         return ($1, $2);
     }
@@ -462,24 +473,24 @@ sub portAlias {
 
 sub rename {
     my ($self, $old_zone_object, $new_zone_object) = @_;
-
+    
     unless ($old_zone_object and $new_zone_object) {
         croak "Error - Need old and new name.\n";
     }
-
+    
     return $self->cmd("zoneObjectRename $old_zone_object, $new_zone_object");
 }
 
 sub _zoning_cmd {
     my ($self, $cmd_name, $zone_object, @cmd_args) = @_;
-
+    
     unless ($cmd_name) {
         croak "Error - Need command name.\n";
     }
     unless ($zone_object) {
         croak "Error - Need object name.\n";
     }
-
+    
     my $cmd = "$cmd_name $zone_object";
     my $str_args;
     if (@cmd_args == 1) {
@@ -493,13 +504,13 @@ sub _zoning_cmd {
     if ($str_args) {
         $cmd .= ", \"$str_args\"";
     }
-
+    
     return $self->cmd($cmd);
 }
 
 sub _build_cmd_name {
     my ($prefix, $args_ref) = @_;
-
+    
     my @exclude = (
         '^-name',
         '^-members',
@@ -518,13 +529,13 @@ sub _build_cmd_name {
     unless ($action) {
         croak "Error - cannot find action.\n";
     }
-
+    
     return $prefix . $action;
 }
 
 sub zone {
     my $self = shift;
-
+    
     my %args = (
         -create  => 0,
         -add     => 0,
@@ -535,13 +546,13 @@ sub zone {
         @_,
     );
     my $cmd_name = _build_cmd_name('zone', \%args);
-
+     
     return $self->_zoning_cmd($cmd_name, $args{-name}, $args{-members});
 }
 
 sub ali {
     my $self = shift;
-
+    
     my %args = (
         -create  => 0,
         -add     => 0,
@@ -552,7 +563,7 @@ sub ali {
         @_,
     );
     my $cmd_name = _build_cmd_name('ali', \%args);
-
+ 
     DEBUG && warn "DEBUG:ALI:", Dumper($cmd_name, \%args);
 
     return $self->_zoning_cmd($cmd_name, $args{-name}, $args{-members});
@@ -573,13 +584,13 @@ Net::Brcd - Perl libraries to contact Brocade switch
 
     #use Net::<Proto>::Brcd;
     use Net::Telnet::Brcd;
-
+    
     #my $sw = new Net::<Proto>::Brcd;
     #Example :
     my $sw = new Net::Telnet::Brcd;
-
+    
     $sw->connect($sw_name,$user,$pass) or die "\n";
-
+    
     %wwn_port = $sw->switchShow(-bywwn=>1);
     my @lines = $sw->cmd("configShow");
 
@@ -621,7 +632,7 @@ Initialize Brocade object. No arguments needed.
     $brcd->connect($switch,$user,$pass);
 
 Connect to a Brocade switch. The command exit if an error
-occured.
+occured. 
 
 B<Do it before any switch command>.
 
@@ -633,7 +644,7 @@ you need several objects.
     my @results = $brcd->cmd("configShow");
     my $ok      = $brcd->cmd("cfgsave");
 
-This function is used to send command to a brocade switch. And implement
+This function is used to send command to a brocade switch. And implement 
 differents features:
 
 =over
@@ -670,7 +681,7 @@ store the stdout of the brocade command and return it in a array.
 
     my $rc = $brcd->sendcmd("portperfshow");
 
-This function execute command without trap standard output. It's useful for
+This function execute command without trap standard output. It's useful for 
 command that needs to be interrupted.
 
 You have to use the C<readline> function to read each line generated by the command.
@@ -687,7 +698,7 @@ Send Ctrl-D command to interrupt command (useful for portperfshow).
         # Do what you want with $str
     }
 
-Read output as piped command. You have a to decided when to stop (If the line
+Read output as piped command. You have a to decided when to stop (If the line 
 content a prompt, I return undef).
 
     $brcd->readline({Timeout => 60});
@@ -705,14 +716,14 @@ of the returned hash :
 
 =item default
 
-Without option : return key = alias, value = WWN.
+Without option : return key = alias, value = WWN. 
 
-B<Be carefull !!> If one alias contains multiple WWN, value is a ref array of
+B<Be carefull !!> If one alias contains multiple WWN, value is a ref array of 
 all the WWN member.
 
 =item -onlywwn
 
-With option -onlywwn => 1 (default option) : does not return alias with port
+With option -onlywwn => 1 (default option) : does not return alias with port 
 naming. Disable this option (-onlywwn => 0), if you want both.
 
 =item -filter
@@ -770,7 +781,7 @@ Return a hash with one key is a zone and value an array of alias member or WWN o
 
 =item -bymember => 1
 
-If you set option C<-bymember => 1>, you have a hash with key a member and value an array of
+If you set option C<< -bymember => 1 >>, you have a hash with key a member and value an array of
 zones where member exists.
 
 =item -filter   => '*'
@@ -785,13 +796,13 @@ It's important to run this command before using the followings functions.
 
     my @member = $brcd->zoneMember("z_sctxp004_0");
 
-Return an array of member of one zone. Need to execute C<$brcd->zoneShow> before.
+Return an array of member of one zone. Need to execute C<< $brcd->zoneShow >> before.
 
 =head2 memberZone
 
     my @zones = $brcd->memberZone("w_sctxp004_0");
 
-Return an array of zones where member exist. Need to execute C<$brcd->zoneShow> before.
+Return an array of zones where member exist. Need to execute C<< $brcd->zoneShow >> before.
 
 =head2 switchShow
 
@@ -813,7 +824,7 @@ If you set C<-bywwn=1>, it's return only a hash of WWN as key and port number as
 
 If you set C<-withportname=1>, the portName command is execute on each port of the switch to get the portname.
 
-If you set C<-byslot=1>, it's return only a hash of slot/number as key and portname and port number
+If you set C<-byslot=1>, it's return only a hash of slot/number as key and portname and port number 
 as value.
 
 =head2 toSlot
@@ -821,7 +832,7 @@ as value.
     my ($slot,$slot_number) = $brcd->toSlot(36);
     my $slot_address        = $brcd->toSlot(36);
 
-The function need to have an exectution of C<$brcd->switchShow>. It's usefull for
+The function need to have an execution of C<< $brcd->switchShow >>. It's usefull for
 a Director Switch to have the translation between absolute port number and slot/port number value.
 
 If you use it in scalar context, the command return the string C<slot/slot_number> (portShow format).
@@ -831,7 +842,7 @@ If you use it in scalar context, the command return the string C<slot/slot_numbe
     my %port     = $brcd->portShow($port_number);
     my $portname = $brcd->portShow($port_number);
 
-Need to have running the C<$brcd->switchShow> command. The function use the C<toSlot>
+Need to have running the C<< $brcd->switchShow >> command. The function use the C<toSlot>
 function before sending the portShow command.
 
 In array context, function return a hash with key as the portName. In scalar context returns the
@@ -883,7 +894,7 @@ Split a string whith zoning format in domain and port number in the switch.
 =head2 cfgSave
 
     my $boolean = $brcd->cfgSave();
-
+    
 The function execute cfgSave command an return true if ok or exit. You can trap
 this exception whith C<eval {};> block. Error message always begin with C<Error - >.
 
@@ -894,7 +905,7 @@ this exception whith C<eval {};> block. Error message always begin with C<Error
         -name    => 'z_toto1',
         -members => '10:00:00:00:C9:3D:F3:04',
     );
-
+        
     my @rc = $brcd->zone(
         -add     => 1,
         -name    => 'z_toto2',
@@ -913,7 +924,7 @@ Supported sub commmand are -add, -create, -delete, -remove.
         -name    => 'w_toto1',
         -members => '10:00:00:00:C9:51:FB:29',
     );
-
+        
     my @rc = $brcd->ali(
         -add     => 1,
         -name    => 'w_toto2',
@@ -922,7 +933,7 @@ Supported sub commmand are -add, -create, -delete, -remove.
             '10:00:00:00:C9:46:DA:A7',
         ],
     );
-
+    
     my @rc = $brcd->ali(
         -add     => 1,
         -name    => 'w_toto3',
@@ -957,11 +968,11 @@ at your option, any later version of Perl 5 you may have available.
 
 =item Version
 
-1.3
+1.5
 
 =item History
 
-Created 6/27/2005, Modified 8/17/07 11:46:09
+Created 6/27/2005, Modified 7/3/10 22:13:07
 
 =back
 
